@@ -93,7 +93,7 @@ static void
 ffs_dinode_lookup(FFS_INFO *ffs, INUM_T inum)
 {
     DADDR_T addr;
-    int     offs;
+    OFF_T     offs;
 	FS_INFO *fs = (FS_INFO *)&ffs->fs_info;
 
     /*
@@ -605,7 +605,7 @@ ffs_block_walk(FS_INFO *fs, DADDR_T start, DADDR_T last, int flags,
  */
 static int
 ffs_file_walk_direct(FS_INFO *fs, FS_BUF *buf,
-  OFF_T length, DADDR_T addr, int flags, FS_FILE_WALK_FN action, char *ptr)
+  size_t length, DADDR_T addr, int flags, FS_FILE_WALK_FN action, char *ptr)
 {
     int     read_count;
     int     myflags;
@@ -618,8 +618,11 @@ ffs_file_walk_direct(FS_INFO *fs, FS_BUF *buf,
 
     if (addr > fs->last_block) {
         if (flags & FS_FLAG_NOABORT)  {
-			fprintf (stderr, "Invalid direct block address (too large): %lu",
-			  (ULONG)addr);
+			if (verbose) {
+				fprintf (logfp, 
+				  "Invalid direct block address (too large): %lu",
+				  (ULONG)addr);
+			}
             return 0;
 		}
 		else {
@@ -671,11 +674,11 @@ ffs_file_walk_direct(FS_INFO *fs, FS_BUF *buf,
  *
  */
 static int
-ffs_file_walk_indir(FS_INFO *fs, FS_BUF *buf[], OFF_T length,
+ffs_file_walk_indir(FS_INFO *fs, FS_BUF *buf[], size_t length,
   DADDR_T addr, int level, int flags, FS_FILE_WALK_FN action, char *ptr)
 {   
     char   *myname = "ffs_file_walk_indir";
-    OFF_T   todo_count = length;
+    size_t   todo_count = length;
     DADDR_T *iaddr;
     int     n;
 
@@ -685,8 +688,11 @@ ffs_file_walk_indir(FS_INFO *fs, FS_BUF *buf[], OFF_T length,
     
     if (addr > fs->last_block) {
         if (flags & FS_FLAG_NOABORT)  {
-        	fprintf (stderr, "Invalid indirect block address (too large): %lu",
-			  (ULONG)addr);
+			if (verbose) {
+				fprintf (logfp, 
+        		  "Invalid indirect block address (too large): %lu",
+				  (ULONG)addr);
+			}
             return 0;
 		}
 		else  {
@@ -720,8 +726,11 @@ ffs_file_walk_indir(FS_INFO *fs, FS_BUF *buf[], OFF_T length,
 
 		if (getu32(fs, (u_int8_t *)&iaddr[n]) > fs->last_block) {
 			if (flags & FS_FLAG_NOABORT) {
-				fprintf (stderr, "Invalid address in indirect list (too large): %lu",
-                  (ULONG)getu32(fs, (u_int8_t *)&iaddr[n]));
+				if (verbose) {
+					fprintf (logfp, 
+					  "Invalid address in indirect list (too large): %lu",
+					  (ULONG)getu32(fs, (u_int8_t *)&iaddr[n]));
+				}
 				return 0;
 			}
 			else {
@@ -756,7 +765,7 @@ void
 ffs_file_walk(FS_INFO *fs, FS_INODE *inode, u_int32_t type, u_int16_t id,
     int flags, FS_FILE_WALK_FN action, char *ptr)
 {    
-    OFF_T   length;
+    size_t   length;
     FS_BUF **buf;
     int     n;
     int     level, retval;
@@ -996,7 +1005,7 @@ ffs_istat (FS_INFO *fs, FILE *hFile, INUM_T inum, int numblock,
     make_ls(fs_inode->mode, ls, 12);
     fprintf(hFile, "mode: %s\n", ls);
 
-	fprintf(hFile, "size: %lu\n", (ULONG) fs_inode->size);
+	fprintf(hFile, "size: %llu\n", (ULLONG) fs_inode->size);
 	fprintf(hFile, "num of links: %lu\n", (ULONG) fs_inode->nlink);
 
 
