@@ -536,7 +536,7 @@ ntfs_dent_walk(FS_INFO *fs, INUM_T inum, int flags,
 		fprintf (logfp, "ntfs_dent_walk: Copying $IDX_ALLOC into buffer\n");
 
 	fs->file_walk(fs, fs_inode, NTFS_ATYPE_IDXALLOC, 0, 
-		FS_FLAG_CONT | FS_FLAG_SLACK,
+		FS_FLAG_CONT | FS_FLAG_SLACK | FS_FLAG_ALLOC | FS_FLAG_UNALLOC,
 		idxalloc_action, "index alloc");
 
 	if (bufleft > 0)
