@@ -1,10 +1,17 @@
 /*
-** The Sleuth Kit
-**
-** Brian Carrier [carrier@sleuthkit.org]
-** Copyright (c) 2003 Brian Carrier.  All rights reserved
-**
-*/
+ * The Sleuth Kit
+ *
+ * Brian Carrier [carrier@sleuthkit.org]
+ * Copyright (c) 2003 Brian Carrier.  All rights reserved
+ *
+ * This file is part of mmtools
+ *
+ * mmtools is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation; either version 2 of the License, or (at your
+ * option) any later version.
+ * 
+ */
 
 #ifndef _MAC_H
 #define _MAC_H
@@ -34,4 +41,10 @@ typedef struct {
 #define MAC_MAGIC	0x504d
 #define MAC_PART_OFFSET	1
 
+#define MAC_STAT_VALID		0x00
+#define MAC_STAT_ALLOC		0x01
+#define MAC_STAT_INUSE		0x02
+#define MAC_STAT_BOOT		0x04
+#define MAC_STAT_READ		0x08
+
 #endif
